/*
 * @(#) TransactionContext.java 
 *
 * JOTM: Java Open Transaction Manager 
 *
 * This project is developed inside the ObjectWeb Consortium,
 * http://www.objectweb.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * Contributor(s): ______________________________________.
 *
 * --------------------------------------------------------------------------
 * $Id: TransactionContext.java,v 1.4 2003/04/17 14:37:27 jmesnil Exp $
 * --------------------------------------------------------------------------
 */
package org.objectweb.jotm;

import java.io.Serializable;
import javax.transaction.xa.Xid;

/**
 * This is how the JTA Implementation in JOTM sees the Transaction Context.
 * This interface is used to keep the code independant of the transport layer
 * this context is for internal use only (JOTM and UserTransaction) it has to 
 * be translated for each protocol. 
 * 
 * For the moment this Transaction Context is Serializable 
 * for test suite 
 * 
 * @author jmesnil
 * @version $Id: TransactionContext.java,v 1.4 2003/04/17 14:37:27 jmesnil Exp $
 */
public interface TransactionContext extends Serializable {
    
    /**
     * get transaction timeout.
     * 
     * @return transaction timeout
     */
    public int getTimeout();
    
    /**
     * get the Coordinator of the transaction.
     * 
     * @return Coordinator
     */
    public Coordinator getCoordinator();
    
    /**
     * set the Coordinator of the transaction.
     * 
     * @param c Coordinator
     */
    public void setCoordinator(Coordinator c);
    
    /**
     * get the Terminator of the transaction.
     * 
     * @return Terminator
     */
    public Terminator getTerminator();
    
    /**
     * get the Control of the Transaction.
     * 
     * @return Control
     */
    public Control getControl();
    
    /**
     * get the Xid of the transaction.
     * 
     * @return Xid
     */
    public Xid getXid();
}
